class Jam < Formula
  desc "Make-like build tool"
  homepage "https://www.perforce.com/documentation/jam-documentation"
  url "https://swarm.workshop.perforce.com/downloads/guest/perforce_software/jam/jam-2.6.1.zip"
  sha256 "72ea48500ad3d61877f7212aa3d673eab2db28d77b874c5a0b9f88decf41cb73"
  license "Jam"

  # The "Jam Documentation" page has a banner stating:
  # "Perforce is no longer actively contributing to the Jam Open Source project.
  # The last Perforce release of Jam was version 2.6 in August of 2014. We will
  # keep the Perforce-controlled links and information posted here available
  # until further notice."
  deprecate! date: "2023-11-02", because: :unmaintained

  conflicts_with "ftjam", because: "both install a `jam` binary"

  # * Ensure <unistd.h> is included on macOS, fixing the following error:
  #   `make1.c:392:8: error: call to undeclared function 'unlink'`.
  # * Fix a typo that leads to an undeclared function error:
  #   `parse.c:102:20: error: call to undeclared function 'yylineno'`
  patch do
    url "https://raw.githubusercontent.com/Homebrew/formula-patches/42252ab3d438f7ada66e83b92bb51a9178d3df10/jam/2.6.1-undeclared_functions.diff"
    sha256 "d567cbaf3914f38bb8c5017ff01cc40fe85970c34d3ad84dbeda8c893518ffae"
  end

  def install
    # Workaround for newer Clang
    ENV.append "CC", "-Wno-implicit-int" if DevelopmentTools.clang_build_version >= 1403

    system "make", "CC=#{ENV.cc}", "CFLAGS=#{ENV.cflags}", "LOCATE_TARGET=bin"
    bin.install "bin/jam", "bin/mkjambase"
  end

  test do
    (testpath/"Jamfile").write <<~EOS
      Main jamtest : jamtest.c ;
    EOS

    (testpath/"jamtest.c").write <<~EOS
      #include <stdio.h>

      int main(void)
      {
          printf("Jam Test\\n");
          return 0;
      }
    EOS

    assert_match "Cc jamtest.o", shell_output(bin/"jam")
    assert_equal "Jam Test", shell_output("./jamtest").strip
  end
end
